/*
 *	
 * Licensed Materials - Property of IBM
 * 
 * SupportPac CB12 
 * 
 * (c) Copyright IBM Corp. 2013, 2014 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication, or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 */
package com.ibm.cics.genapp.customer.search.web;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ibm.cics.server.AbendException;
import com.ibm.cics.server.InvalidProgramIdException;
import com.ibm.cics.server.InvalidRequestException;
import com.ibm.cics.server.InvalidSystemIdException;
import com.ibm.cics.server.LengthErrorException;
import com.ibm.cics.server.NotAuthorisedException;
import com.ibm.cics.server.Program;
import com.ibm.cics.server.RolledBackException;
import com.ibm.cics.server.TerminalException;

/**
 * Servlet implementation class FetchData
 */
@WebServlet("/FetchData")
public class FetchData extends HttpServlet 
{
    // <copyright 
    // notice="cics-lm-java-class" 
    // pids="SupportPac CB12" 
    // years="2013,2014" > 
	static final String COPYRIGHT = "Licensed Materials - Property of IBM SupportPac CB12 (c) Copyright IBM Corp. 2013 2014 All Rights Reserved. US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp."; 
    // </copyright> 

	private static final long serialVersionUID = 1L;
	
	/**
	 * The LOCALCCSID from the CICS System Initialization Table
     */
	private static String LOCAL_CCSID = System.getProperty("com.ibm.cics.jvmserver.local.ccsid");
	
    /**
     * @see HttpServlet#HttpServlet()
     */
    public FetchData() 
    {
        super();
    }

	/**
	 * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException 
	{		
		// set the response type
		response.setContentType("text/xml");		
		
		// begin writing XML out to the response output stream
		PrintWriter out = response.getWriter();
		
		// get the customer number from the request
		String cusNum = request.getParameter("cusNum");		
		if(cusNum.length() < 10) 
		{
			//Add left padding of 0s to make up to 10
			try 
			{
				cusNum = String.format("%010d", Integer.parseInt(cusNum));  
			} 
			catch (NumberFormatException nfe) 
			{
				//If not a number, return error.
				out.println("<response>");					
				out.println("<record>");	
				out.println("<row><name>Error:</name><value>Customer Number must only contain numbers</value></row>");
				out.println("</record>");
				out.println("</response>");
				out.close();
				return;
			}
		}
		
		if(cusNum.length() > 10) 
		{
			//If more than 10, return error.
			out.println("<response>");					
			out.println("<record>");	
			out.println("<row><name>Error:</name><value>Customer Number must be 10 digits or less</value></row>");
			out.println("</record>");
			out.println("</response>");
			out.close();
			return;
		}
		
		//Create a new commarea with the local ccsid encoding type
		InquiryCommarea inqcom = new InquiryCommarea(LOCAL_CCSID);
		
		//Set the customer number on the commarea
		inqcom.setCus_num(cusNum);
		
		Exception error = null;
		try 
		{
			//Create a new program to link to GENAPP LGICUS01 customer inquire program
			Program p = new Program();
			p.setName("LGICUS01");
			
			//Exec cics link with the commarea byte array
			p.link(inqcom.getByteArray());
			
		} 
		catch (InvalidRequestException e) 
		{
			e.printStackTrace();
			error = e;
		} 
		catch (LengthErrorException e) 
		{
			e.printStackTrace();
			error = e;
		} 
		catch (InvalidSystemIdException e) 
		{
			e.printStackTrace();
			error = e;
		} 
		catch (NotAuthorisedException e) 
		{
			e.printStackTrace();
			error = e;
		} 
		catch (InvalidProgramIdException e) 
		{
			e.printStackTrace();
			error = e;
		} 
		catch (RolledBackException e) 
		{
			e.printStackTrace();
			error = e;
		} 
		catch (TerminalException e) 
		{
			e.printStackTrace();
			error = e;
		} 
		catch (AbendException e) 
		{
			e.printStackTrace();
			error = e;
		}
		
		out.println("<response>");					
		out.println("<record>");	

		//If error has been caught, return the error
		if(error != null) 
		{
			out.println("<row><name>Error:</name><value>" + error + "</row>");	
		} 
		else 
		{
			//No errors, print out the value of each commarea field
			out.println("<row><name>CusNum:</name><value>" + inqcom.getCus_num() + "</value></row>");	
			out.println("<row><name>First Name:</name><value>" + inqcom.getFirst_name() + "</value></row>");	
			out.println("<row><name>Last Name:</name><value>" + inqcom.getLast_name() + "</value></row>");	
			out.println("<row><name>House Name:</name><value>" + inqcom.getHouse_name() + "</value></row>");	
			out.println("<row><name>House Num:</name><value>" + inqcom.getHouse_num() + "</value></row>");	
			out.println("<row><name>Post Code:</name><value>" + inqcom.getPost_code() + "</value></row>");	
			out.println("<row><name>DOB:</name><value>" + inqcom.getDob() + "</value></row>");	
		}
		out.println("</record>");
		
		// complete the XML before returning
		out.println("</response>");
		out.close();
	
	}

	/**
	 * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException 
	{
		doGet(request, response);
	}

}
