/*
 *	
 * Licensed Materials - Property of IBM
 * 
 * SupportPac CB12 
 * 
 * (c) Copyright IBM Corp. 2013, 2014 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication, or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 */
package com.ibm.cics.genapp.customer.search.web;

import java.io.UnsupportedEncodingException;


public class InquiryCommarea 
{
    // <copyright 
    // notice="cics-lm-java-class" 
    // pids="SupportPac CB12" 
    // years="2013,2014" > 
	static final String COPYRIGHT = "Licensed Materials - Property of IBM SupportPac CB12 (c) Copyright IBM Corp. 2013 2014 All Rights Reserved. US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp."; 
    // </copyright> 
	
	private final int[] commarea_buffer = {0,32500}; //Length of commarea
	private final int[] return_code = {6,2}; //Allocation for return code
	private final int[] cus_num = {8, 10}; //Allocation for customer number
	private final int[] first_name = {18, 10}; //Allocation for first name
	private final int[] last_name = {28, 20}; //Allocation for last name
	private final int[] dob = {48, 10}; //Allocation for date of birth
	private final int[] house_name = {58, 20}; //Allocation for house name
	private final int[] house_num = {78, 4}; //Allocation for house number
	private final int[] post_code = {82, 8}; //Allocation for post code 
	
	// Final Data
	private byte[] fData;
	
	// Local ccsid of CICS
	private String ccsid;
	
	public InquiryCommarea(String cicsEncoding) 
	{
		// Set the encoding to use
		this.ccsid = cicsEncoding;
		
		// Create a new byte array with length of commarea
		fData = new byte[commarea_buffer[1]];
		
		// Initialize array with spaces
		setNewValue(" ", 0, fData.length);
	}
	
	public byte[] getByteArray() 
	{
		return fData;
	}

	private String getData(int pos, int length) 
	{
		try 
		{
			// Return string for given position and length in correct encoding
			return new String(fData, pos, length, ccsid);
		} 
		catch (UnsupportedEncodingException e) 
		{
			return "";
		}
	}

	public String getReturn_code() 
	{
		return getData(return_code[0], return_code[1]);
	}

	public String getCus_num() 
	{
		return getData(cus_num[0], cus_num[1]);
	}

	public String getFirst_name() 
	{
		return getData(first_name[0], first_name[1]);
	}

	public String getLast_name() 
	{
		return getData(last_name[0], last_name[1]);
	}

	public String getDob() 
	{
		return getData(dob[0], dob[1]);
	}

	public String getHouse_name() 
	{
		return getData(house_name[0], house_name[1]);
	}

	public String getHouse_num() 
	{
		return getData(house_num[0], house_num[1]);
	}

	public String getPost_code() 
	{
		return getData(post_code[0], post_code[1]);
	}
	
	public void setReturn_code(String value) 
	{
		setNewValue(value, return_code[0], return_code[1]);
	}

	public void setCus_num(String value) 
	{
		setNewValue(value, cus_num[0], cus_num[1]);
	}

	public void setFirst_name(String value) 
	{
		setNewValue(value, first_name[0], first_name[1]);
	}

	public void setLast_name(String value) 
	{
		setNewValue(value, last_name[0], last_name[1]);
	}

	public void setDob(String value) 
	{
		setNewValue(value, dob[0], dob[1]);
	}

	public void setHouse_name(String value) 
	{
		setNewValue(value, house_name[0], house_name[1]);
	}

	public void setHouse_num(String value) 
	{
		setNewValue(value, house_num[0], house_num[1]);
	}

	public void setPost_code(String value) 
	{
		setNewValue(value, post_code[0], post_code[1]);
	}
	
	private void setNewValue(String newValue, int index, int length) 
	{
		byte[] byteValue;
		byte space;
		
		// Get the space byte for padding (in CICS encoding)
		try 
		{
			space = " ".getBytes(ccsid)[0];
		}
		catch(UnsupportedEncodingException e)
		{
			// Failover to default encoding
			space = " ".getBytes()[0];
		}
		
		// Get the bytes of string (in CICS encoding)
		try
		{
			byteValue = newValue.getBytes(ccsid);
		}	
		catch (UnsupportedEncodingException e) 
		{		
			// Fail over to default encoding
			byteValue = newValue.getBytes();
		}
		
		// Loop through the string and insert it into final data
		// Space pad if string is less than fixed data length.
		for(int i = 0; i < length; i++)
		{
			// Initialise to space byte
			byte val = space;
				
			// If there is still data to insert into final string do it,
			// otherwise space-pad.
			if (i < byteValue.length) 
			{
				val = byteValue[i];
			}			
			fData[index+i] = val;
		}		
	}	
}
